==> haskell-hslua-marshalling-2.3.1-134.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-marshalling.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-marshalling
version:              2.3.1
visibility:           public
id:                   hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
key:                  hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Marshalling of values between Haskell and Lua.
description:
    Provides functions to marshal values from Haskell
    to Lua, and /vice versa/.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  9a01ffa69892eb107e6ed0229c2d81be
exposed:              True
exposed-modules:
    HsLua.Marshalling HsLua.Marshalling.Peek HsLua.Marshalling.Peekers
    HsLua.Marshalling.Push HsLua.Marshalling.Userdata

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-marshalling
hs-libraries:         HShslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-marshalling/html/hslua-marshalling.haddock

haddock-html:         /usr/share/doc/haskell-hslua-marshalling/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-marshalling-2.3.1-135-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-marshalling.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-marshalling
version:              2.3.1
visibility:           public
id:                   hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
key:                  hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Marshalling of values between Haskell and Lua.
description:
    Provides functions to marshal values from Haskell
    to Lua, and /vice versa/.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  7a0855a0fb26c01d179f8787a06d3d92
exposed:              True
exposed-modules:
    HsLua.Marshalling HsLua.Marshalling.Peek HsLua.Marshalling.Peekers
    HsLua.Marshalling.Push HsLua.Marshalling.Userdata

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-marshalling
hs-libraries:         HShslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-marshalling/html/hslua-marshalling.haddock

haddock-html:         /usr/share/doc/haskell-hslua-marshalling/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
